@@ -15,7 +15,7 @@ class DateUtils(object):
             time_unit = TimeUnitType.to_enum(
                 SystemParameter.find_one("DEFAULT_TIME_UNIT",
                                          FieldDataType.STRING,
-                                         TimeUnitType.HOUR.value))
+                                         TimeUnitType.HOUR))
 
         if time_unit == TimeUnitType.YEAR:
             return days / 365
