@@ -1,8 +1,10 @@
 from .api_document_submit_view import ApiDocumentSubmitView
 from .api_document_upload_view import ApiDocumentUploadView
+from .api_latest_document_view import ApiLatestDocumentView
 
 
 __all__ = [
     ApiDocumentSubmitView,
     ApiDocumentUploadView,
+    ApiLatestDocumentView
 ]
